==> openshift-model-console-5.7.3-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleExternalLogLinkSpecBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConsoleExternalLogLinkSpecBuilder extends io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpec,io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecBuilder>{
  public ConsoleExternalLogLinkSpecBuilder() {
    this(false);
  }
  public ConsoleExternalLogLinkSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ConsoleExternalLogLinkSpec(), validationEnabled);
  }
  public ConsoleExternalLogLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleExternalLogLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConsoleExternalLogLinkSpec(), validationEnabled);
  }
  public ConsoleExternalLogLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpec instance) {
    this(fluent, instance, false);
  }
  public ConsoleExternalLogLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withHrefTemplate(instance.getHrefTemplate()); 
    fluent.withNamespaceFilter(instance.getNamespaceFilter()); 
    fluent.withText(instance.getText()); 
    this.validationEnabled = validationEnabled; 
  }
  public ConsoleExternalLogLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpec instance) {
    this(instance,false);
  }
  public ConsoleExternalLogLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withHrefTemplate(instance.getHrefTemplate()); 
    this.withNamespaceFilter(instance.getNamespaceFilter()); 
    this.withText(instance.getText()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpec build() {
    ConsoleExternalLogLinkSpec buildable = new ConsoleExternalLogLinkSpec(fluent.getHrefTemplate(),fluent.getNamespaceFilter(),fluent.getText());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleExternalLogLinkSpecBuilder that = (ConsoleExternalLogLinkSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-console-5.12.2-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleExternalLogLinkSpecBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConsoleExternalLogLinkSpecBuilder extends io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpec,io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecBuilder>{
  public ConsoleExternalLogLinkSpecBuilder() {
    this(false);
  }
  public ConsoleExternalLogLinkSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ConsoleExternalLogLinkSpec(), validationEnabled);
  }
  public ConsoleExternalLogLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleExternalLogLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConsoleExternalLogLinkSpec(), validationEnabled);
  }
  public ConsoleExternalLogLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpec instance) {
    this(fluent, instance, false);
  }
  public ConsoleExternalLogLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withHrefTemplate(instance.getHrefTemplate()); 
    fluent.withNamespaceFilter(instance.getNamespaceFilter()); 
    fluent.withText(instance.getText()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConsoleExternalLogLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpec instance) {
    this(instance,false);
  }
  public ConsoleExternalLogLinkSpecBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withHrefTemplate(instance.getHrefTemplate()); 
    this.withNamespaceFilter(instance.getNamespaceFilter()); 
    this.withText(instance.getText()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.console.v1.ConsoleExternalLogLinkSpec build() {
    ConsoleExternalLogLinkSpec buildable = new ConsoleExternalLogLinkSpec(fluent.getHrefTemplate(),fluent.getNamespaceFilter(),fluent.getText());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleExternalLogLinkSpecBuilder that = (ConsoleExternalLogLinkSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
